***
API
***

Public
======

.. py:module:: pydiverse.common

.. autoclass:: Dtype
   :members:
.. autoclass:: Bool
   :members:
.. autoclass:: Date
   :members:
.. autoclass:: Datetime
   :members:
.. autoclass:: Decimal
   :members:
.. autoclass:: Duration
   :members:
.. autoclass:: Float
   :members:
.. autoclass:: Float32
   :members:
.. autoclass:: Float64
   :members:
.. autoclass:: Int
   :members:
.. autoclass:: Int8
   :members:
.. autoclass:: Int16
   :members:
.. autoclass:: Int32
   :members:
.. autoclass:: Int64
   :members:
.. autoclass:: NullType
   :members:
.. autoclass:: String
   :members:
.. autoclass:: Time
   :members:
.. autoclass:: UInt8
   :members:
.. autoclass:: UInt16
   :members:
.. autoclass:: UInt32
   :members:
.. autoclass:: UInt64
   :members:
.. autoclass:: List
   :members:
.. autoclass:: PandasBackend
   :members:
